@@ -1,9 +1,7 @@
 #!/usr/bin/perl
 
-package Main;
-
 # This file is part of the pnopaste program
-# Copyright (C) 2008-2009 Patrick Matthäi <patrick@linux-dev.org>
+# Copyright (C) 2008-2010 Patrick Matthäi <pmatthaei@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,13 +37,20 @@ sub Main {
 	my $Full_URL = $CGI->url(-full => 1);
 	my $Remote_Addr = $CGI->remote_host();
 
+	if(!defined $Full_URL){
+		$Full_URL = 'none';
+	}
+	if(!defined $Remote_Addr){
+		$Remote_Addr = 'none';
+	}
+
 	# Block all banned IPs directly.
 	if(Security::Blacklist_Host($Remote_Addr) == 1){
 		HTML::Error(2);
 	}
 
+	#Clean up database from expired entries.
 	if(Expire::Get_Cleanup()){
-		# Clean up database.
 		Expire::Delete_Old_Entrys();
 	}
 
