@@ -1,7 +1,7 @@
 package Translation;
 
 # This file is part of the pnopaste program
-# Copyright (C) 2008-2009 Patrick Matthäi <patrick@linux-dev.org>
+# Copyright (C) 2008-2010 Patrick Matthäi <pmatthaei@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ our %Strings = (
 	11	=> 'Coloration syntaxique:',
 	12	=> 'Description:',
 	13	=> 'Code:',
-	14	=> 'Inseré:',
+	14	=> 'Insérer:',
 	15	=> 'Bonjour, Votre code a été ajouté avec succès.',
 	16	=> 'Vous pouvez, maintenant, acceder à votre paste sur',
 	17	=> 'Vous pouvez également obtenir un lien vers une ligne spécifique, par exemple:',
