@@ -1,7 +1,7 @@
 package Code;
 
 # This file is part of the pnopaste program
-# Copyright (C) 2008-2009 Patrick Matthäi <patrick@linux-dev.org>
+# Copyright (C) 2008-2010 Patrick Matthäi <pmatthaei@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ sub Add {
         }
 
         # Create query with all needed data.
-        my $Query = 'INSERT INTO `nopaste` (name, description, code, time, ip, expires, language) VALUES (?, ?, ?, ?, ?, ?, ?)';
+        my $Query = 'INSERT INTO nopaste (name, description, code, time, ip, expires, language) VALUES (?, ?, ?, ?, ?, ?, ?)';
         $Query = $Database::dbh->prepare($Query);
         $Query->execute($Name, $Desc, $Code, time(), $Remote_Addr, $Expire::Time_List{$Expi}, $Synt);
 
