@@ -1,7 +1,7 @@
 package HTML;
 
 # This file is part of the pnopaste program
-# Copyright (C) 2008-2009 Patrick Matthäi <patrick@linux-dev.org>
+# Copyright (C) 2008-2010 Patrick Matthäi <pmatthaei@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -165,7 +165,7 @@ sub Add {
 sub Code {
 	my($ID, $Download, $BaseURL) = @_;
 
-	my $Query = 'SELECT name,description,code,time,ip,language FROM `nopaste` WHERE id = ? LIMIT 1';
+	my $Query = 'SELECT name,description,code,time,ip,language FROM nopaste WHERE id = ? LIMIT 1';
 	$Query = $Database::dbh->prepare($Query);
 	$Query->execute($ID);
 
